@@ -345,6 +345,8 @@ const char *BayonneSession::getExternal(const char *id)
 			return var_callid;
 		else if(!stricmp(id, "timeslot"))
 			return var_timeslot;
+		else if(!stricmp(id, "servertype"))
+			return "sa";
 		else if(!stricmp(id, "deviceid"))
 			return logname;
 		else if(!stricmp(id, "voice"))
