@@ -980,6 +980,9 @@ bool Methods::scrRecord(void)
         }
 
 	state.audio.list[0] = getValue(NULL);
+	state.audio.list[1] = getValue(NULL);
+	state.audio.list[2] = NULL;
+
 	state.audio.mode = Audio::modeCreate;
 	if(audio.offset)
 		state.audio.mode = Audio::modeWrite;
@@ -1027,6 +1030,8 @@ bool Methods::scrAppend(void)
         }
 
 	state.audio.list[0] = getValue(NULL);
+	state.audio.list[1] = getValue(NULL);
+	state.audio.list[2] = NULL;
 	state.audio.mode = Audio::modeAppend;
 
 	setState(STATE_RECORD);
